@@ -19,6 +19,8 @@ VAT_NUMBERS = [
     ('AL', 'AA9999999L', False),
     ('AL', 'KA9999999L', False),
     ('AL', 'K999999991', False),
+    ('AR', '00000000000', True),
+    ('AR', '00000000001', False),
     ('BE', '0123456749', True),
     ('BE', '0897290877', True),
     ('BE', '01234567490', False),
@@ -162,6 +164,7 @@ VAT_NUMBERS = [
     ('RO', '24736200', True),
     ('RO', '1234567897', True),
     ('RO', '1630615123457', True),
+    ('RO', '-7793957', False),
     ('RU', '5505035011', True),
     ('RU', '550501929014', True),
     ('SE', '123456789701', True),
@@ -193,7 +196,7 @@ class VatNumberTest(unittest.TestCase):
         '''
         for code, number, result in VAT_NUMBERS:
             if result:
-                test = self.assert_
+                test = self.assertTrue
             else:
                 test = self.assertFalse
             test(vatnumber.check_vat(code + number), code + number)
